@@ -2,35 +2,33 @@
 
 use strict;
 use lib '../lib';
-use Continuity::Server::Simple;
+use Continuity;
+use Coro;
+use Coro::Event;
 
-my $server = Continuity::Server::Simple->new(
-    port => 8081,
-);
-
-$server->loop;
+my $server = new Continuity;
+Event::loop();
 
 sub main {
-  $server->get_request;
-  print qq{
+  my $request = shift;
+  $request->next;
+  $request->print(qq{
     <form>
       Enter first number:
       <input type=text name=num><input type=submit>
     </form>
-  };
-  my $params = $server->get_request->params;
-  my $num1 = $params->{num};
-  print qq{
+  });
+  my $num1 = $request->next->param('num');
+  $request->print(qq{
     <form>
       Enter second number:
       <input type=text name=num><input type=submit>
     </form>
-  };
-  $params = $server->get_request->params;
-  my $num2 = $params->{num};
+  });
+  my $num2 = $request->next->param('num');
   my $sum = $num1 + $num2;
-  print qq{
+  $request->print(qq{
     <h2>The sum of $num1 and $num2 is $sum!</h2>
-  }
+  });
 }
 
